:py:mod:`piel.models.frequency.photonic.directional_coupler_simple`
===================================================================

.. py:module:: piel.models.frequency.photonic.directional_coupler_simple

.. autoapi-nested-parse::

   Translated from https://github.com/flaport/sax or https://github.com/flaport/photontorch/tree/master



Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   piel.models.frequency.photonic.directional_coupler_simple.directional_coupler



.. py:function:: directional_coupler(coupling=0.5)
